@@ -92,38 +92,65 @@ def bhvRDM(bhv_data, sub_opt=0, data_opt=1):
 
 ' a function for calculating the RDM based on EEG/MEG/fNIRS data '
 
-def eegRDM(EEG_data, time_win=5, sub_opt=0, chl_opt=0, time_opt=0):
+def eegRDM(EEG_data, sub_opt=0, chl_opt=0, time_opt=0, time_win=5):
     # shape of EEG_data: [n_cons, n_subs,_n_trials, n_chls, n_ts]
     # n_cons, n_subs, n_trials, n_chls, n_frqs, n_ts represent the number of
     # the conditions, subjects, trials, channels, frequencies and time-points
-    # time_win : the time-window, if time_win=5, that means each calculation process bases on 5 time points
-    #            this is also a processing of downsampling
     # sub_opt : 0 : return only one rdm
     #           1 : each subject obtains a rdm
     # chl_opt : 0 : consider all the channels
     #           1 : each channel obtains a rdm
     # time_opt : 0 : consider the time sequence
     #            1 : each time-point obtains a rdm
+    # time_win : the time-window, if time_win=5, that means each calculation process bases on 5 time points
+    #            this is also a processing of downsampling
 
     cons, subs, trials, chls, ts = np.shape(EEG_data)  # get the number of conditions, subjects, trials,
-                                                       # channels and time points
+    # channels and time points
 
     if sub_opt == 1:
 
         if time_opt == 1:
 
-            ts = int(ts/time_win)
+            ts = int(ts / time_win)
 
             if chl_opt == 1:
-                return None
 
-            data = np.zeros([subs, ts, cons, chls], dtype=np.float64)
+                # sub_opt=1 & time_opt=1 & chl_opt=1
+
+                data = np.zeros([subs, chls, ts, cons, time_win], dtype=np.float64)
+
+                for i in range(subs):
+                    for j in range(chls):
+                        for k in range(ts):
+                            for l in range(cons):
+                                for m in range(time_win):
+                                    data[i, j, k, l, m] = np.average(EEG_data[l, i, :, j, k * time_win + m])
+
+                rdms = np.zeros([subs, chls, ts, cons, cons], dtype=np.float64)
+
+                for i in range(subs):
+                    for j in range(chls):
+                        for k in range(ts):
+                            for l in range(cons):
+                                for m in range(cons):
+                                    r = pearsonr(data[i, j, k, l], data[i, j, k, m])[0]
+                                    rdms[i, j, k, l, m] = limtozero(1 - abs(r))
+
+                return rdms
+
+            # sub_opt=1 & time_opt=1 & chl_opt=0
+
+            data = np.zeros([subs, ts, cons, chls, time_win], dtype=np.float64)
 
             for i in range(subs):
                 for j in range(ts):
                     for k in range(cons):
                         for l in range(chls):
-                            data[i, j, k, l] = np.average(EEG_data[k, i, :, l, j*time_win:j*time_win+time_win])
+                            for m in range(time_win):
+                                data[i, j, k, l, m] = np.average(EEG_data[k, i, :, l, j * time_win + m])
+
+            data = np.reshape(data, [subs, ts, cons, chls * time_win])
 
             rdms = np.zeros([subs, ts, cons, cons], dtype=np.float64)
 
@@ -142,6 +169,8 @@ def eegRDM(EEG_data, time_win=5, sub_opt=0, chl_opt=0, time_opt=0):
 
         if chl_opt == 1:
 
+            # sub_opt=1 & time_opt=0 & chl_opt=1
+
             data = np.zeros([subs, chls, cons, ts], dtype=np.float64)
 
             for i in range(subs):
@@ -163,7 +192,7 @@ def eegRDM(EEG_data, time_win=5, sub_opt=0, chl_opt=0, time_opt=0):
 
         # if chl_opt = 0
 
-        cons, subs, trials, chls, ts = np.shape(EEG_data)
+        # sub_opt=1 & time_opt=0 & chl_opt=0
 
         data = np.zeros([subs, cons, chls, ts], dtype=np.float64)
 
@@ -173,7 +202,7 @@ def eegRDM(EEG_data, time_win=5, sub_opt=0, chl_opt=0, time_opt=0):
                     for l in range(ts):
                         data[i, j, k, l] = np.average(EEG_data[j, i, :, k, l])
 
-        data = np.reshape(data, [subs, cons, chls*ts])
+        data = np.reshape(data, [subs, cons, chls * ts])
 
         rdms = np.zeros([subs, cons, cons], dtype=np.float64)
 
@@ -182,7 +211,6 @@ def eegRDM(EEG_data, time_win=5, sub_opt=0, chl_opt=0, time_opt=0):
             for j in range(cons):
 
                 for k in range(cons):
-
                     r = pearsonr(data[i, j], data[i, k])[0]
 
                     rdms[i, j, k] = limtozero(1 - abs(r))
@@ -191,16 +219,39 @@ def eegRDM(EEG_data, time_win=5, sub_opt=0, chl_opt=0, time_opt=0):
 
     # if sub_opt = 0
 
-    cons, subs, trials, chls, ts = np.shape(EEG_data)
-
     if time_opt == 1:
 
-        ts = int(ts/time_win)
+        ts = int(ts / time_win)
 
         if chl_opt == 1:
-            return None
 
-        data = np.zeros([ts, cons, subs, chls], dtype=np.float64)
+            # sub_opt=0 & time_opt=1 & chl_opt=1
+
+            data = np.zeros([chls, ts, cons, subs, time_win], dtype=np.float64)
+
+            for i in range(chls):
+                for j in range(ts):
+                    for k in range(cons):
+                        for l in range(subs):
+                            for m in range(time_win):
+                                data[i, j, k, l, m] = np.average(EEG_data[k, l, :, i, j * time_win + m])
+
+            data = np.reshape(data, [chls, ts, cons, subs * time_win])
+
+            rdms = np.zeros([chls, ts, cons, cons], dtype=np.float64)
+
+            for i in range(chls):
+                for j in range(ts):
+                    for k in range(cons):
+                        for l in range(cons):
+                            r = pearsonr(data[i, j, k], data[i, j, l])[0]
+                            rdms[i, j, k, l] = limtozero(1 - abs(r))
+
+            return rdms
+
+        # sub_opt=0 & time_opt=1 & chl_opt=0
+
+        data = np.zeros([ts, cons, subs, chls, time_win], dtype=np.float64)
 
         for i in range(ts):
 
@@ -210,9 +261,10 @@ def eegRDM(EEG_data, time_win=5, sub_opt=0, chl_opt=0, time_opt=0):
 
                     for l in range(chls):
 
-                        data[i, j, k, l] = np.average(EEG_data[j, k, :, l, i*time_win:i*time_win+time_win])
+                        for m in range(time_win):
+                            data[i, j, k, l, m] = np.average(EEG_data[j, k, :, l, i * time_win + m])
 
-        data = np.reshape(data, [ts, cons, subs * chls])
+        data = np.reshape(data, [ts, cons, subs * chls * time_win])
 
         rdms = np.zeros([ts, cons, cons], dtype=np.float64)
 
@@ -221,7 +273,6 @@ def eegRDM(EEG_data, time_win=5, sub_opt=0, chl_opt=0, time_opt=0):
             for j in range(cons):
 
                 for k in range(cons):
-
                     r = pearsonr(data[i, j], data[i, k])[0]
 
                     rdms[i, j, k] = limtozero(1 - abs(r))
@@ -229,6 +280,9 @@ def eegRDM(EEG_data, time_win=5, sub_opt=0, chl_opt=0, time_opt=0):
         return rdms
 
     # if time_opt = 0
+
+    # sub_opt=0 & time_opt=0 & chl_opt=1
+
     cons, subs, trials, chls, ts = np.shape(EEG_data)
 
     if chl_opt == 1:
@@ -242,10 +296,9 @@ def eegRDM(EEG_data, time_win=5, sub_opt=0, chl_opt=0, time_opt=0):
                 for k in range(subs):
 
                     for l in range(ts):
-
                         data[i, j, k, l] = np.average(EEG_data[j, k, :, i, l])
 
-        data = np.reshape(data, [chls, cons, subs*ts])
+        data = np.reshape(data, [chls, cons, subs * ts])
 
         rdms = np.zeros([chls, cons, cons], dtype=np.float64)
 
@@ -254,7 +307,6 @@ def eegRDM(EEG_data, time_win=5, sub_opt=0, chl_opt=0, time_opt=0):
             for j in range(cons):
 
                 for k in range(cons):
-
                     r = pearsonr(data[i, j], data[i, k])[0]
 
                     rdms[i, j, k] = limtozero(1 - abs(r))
@@ -263,6 +315,8 @@ def eegRDM(EEG_data, time_win=5, sub_opt=0, chl_opt=0, time_opt=0):
 
     # if chl_opt = 0
 
+    # sub_opt=0 & time_opt=0 & chl_opt=0
+
     cons, subs, trials, chls, ts = np.shape(EEG_data)
 
     data = np.zeros([cons, subs, chls, ts], dtype=np.float64)
@@ -274,7 +328,6 @@ def eegRDM(EEG_data, time_win=5, sub_opt=0, chl_opt=0, time_opt=0):
             for k in range(chls):
 
                 for l in range(ts):
-
                     data[i, j, k, l] = np.average(EEG_data[i, j, :, k, l])
 
     data = np.reshape(data, [cons, subs * chls * ts])
@@ -284,7 +337,6 @@ def eegRDM(EEG_data, time_win=5, sub_opt=0, chl_opt=0, time_opt=0):
     for i in range(cons):
 
         for j in range(cons):
-
             r = pearsonr(data[i], data[j])[0]
 
             rdm[i, j] = limtozero(1 - np.abs(r))
@@ -293,14 +345,14 @@ def eegRDM(EEG_data, time_win=5, sub_opt=0, chl_opt=0, time_opt=0):
 
 ' a function for calculating the RDM based on ECoG/electrophysiological data '
 
-def ecogRDM(ele_data, time_win=5, opt="all"):
+def ecogRDM(ele_data, opt="all", time_win=5):
     # all these calculations belong to only one subject
     # nchls represent the number of channels of the data
     # the shape of ele_data : [N_cons, N_trials, N_chls, N_ts]
-    # time_win : the time-window, if time_win=5, that means each calculation process bases on 5 time points
-    #            this is also a processing of downsampling
     # N_cons, N_trials, N_chls, N_ts represent the number of conditions,
     # the number of trials, the number of channels, the number of time-points
+    # time_win : the time-window, if time_win=5, that means each calculation process bases on 5 time points
+    #            this is also a processing of downsampling
 
     cons, trials, chls, ts = np.shape(ele_data)  #  get the number of conditins, trials, channels and time points
 
@@ -334,7 +386,7 @@ def ecogRDM(ele_data, time_win=5, opt="all"):
 
         ts = int(ts/time_win)
 
-        data = np.zeros([ts, cons, chls], dtype=np.float64)
+        data = np.zeros([ts, cons, chls, ts], dtype=np.float64)
 
         for i in range(ts):
 
@@ -342,7 +394,11 @@ def ecogRDM(ele_data, time_win=5, opt="all"):
 
                 for k in range(chls):
 
-                    data[i, j, k] = np.average(ele_data[j, :, k, i*time_win:i*time_win+time_win])
+                    for l in range(ts):
+
+                        data[i, j, k, l] = np.average(ele_data[j, :, k, i*time_win+l])
+
+        data = np.reshape(data, [ts, cons, chls*ts])
 
         rdms = np.zeros([ts, cons, cons], dtype=np.float64)
 
